@@ -1,7 +1,6 @@
 "predict.surface" <-
-function (out, grid.list = NA, extrap = FALSE, chull.mask, model = NA, nx=30, 
-ny=30,
-    ...) 
+function (out, grid.list = NA, extrap = FALSE, chull.mask, model = NA, 
+    nx = 30, ny = 30, ...) 
 {
     if ((length(grid.list) == 1) | (is.na(grid.list)[1])) {
         if (is.null(out$x)) 
@@ -18,8 +17,9 @@ ny=30,
         names(grid.list) <- temp
     }
     if (is.null(out$x)) 
-        xg <- make.surface.grid(grid.list, nx=nx, ny=ny)
-    else xg <- make.surface.grid(grid.list, X = out$x, nx=nx,ny=ny)
+        xg <- make.surface.grid(grid.list, nx = nx, ny = ny)
+    else xg <- make.surface.grid(grid.list, X = out$x, nx = nx, 
+        ny = ny)
     out2 <- as.surface(xg, predict(out, xg, model = model, ...))
     if (!extrap) {
         if (missing(chull.mask)) {
@@ -27,7 +27,7 @@ ny=30,
             chull.mask <- unique.matrix(out$x[, ind])
         }
         chull.mask <- chull.mask[chull(chull.mask), ]
-        out2$z[in.poly(xg, xp = chull.mask) == 0] <- NA
+        out2$z[in.poly(xg[,ind], xp = chull.mask) == 0] <- NA
     }
     out2
 }
